**Example 1: 修改应用代理的状态**



Input: 

```
tccli teo ModifyApplicationProxyStatus --cli-unfold-argument  \
    --ZoneId zone-276zs184g93m \
    --ProxyId proxy-19389e5dwwxfs \
    --Status online
```

Output: 
```
{
    "Response": {
        "RequestId": "5e0a2b4e-df6d-4d2a-ac39-1706cbf8a707"
    }
}
```

